Class: Pikuri::Skill::Catalog::Empty
- Inherits:
-
Catalog
- Object
- Catalog
- Pikuri::Skill::Catalog::Empty
- Defined in:
- lib/pikuri/skill/catalog.rb
Overview
Null-object catalog. The EMPTY constant is the singleton used
as the default when no skills are wired in.
Instance Method Summary collapse
- #get(_name) ⇒ Object
- #list ⇒ Object
- #roots ⇒ Object
-
#untrusted_level ⇒ Symbol
:none— a catalog that loaded no bytes contributes no untrusted content, which is the union over zero skills.
Instance Method Details
#get(_name) ⇒ Object
106 107 108 |
# File 'lib/pikuri/skill/catalog.rb', line 106 def get(_name) nil end |
#list ⇒ Object
102 103 104 |
# File 'lib/pikuri/skill/catalog.rb', line 102 def list [].freeze end |
#roots ⇒ Object
110 111 112 |
# File 'lib/pikuri/skill/catalog.rb', line 110 def roots [].freeze end |
#untrusted_level ⇒ Symbol
Returns :none — a catalog that loaded no bytes contributes
no untrusted content, which is the union over zero skills.
116 |
# File 'lib/pikuri/skill/catalog.rb', line 116 def untrusted_level = :none |